@@ -327,7 +327,7 @@ def calculate_win_rate(df_csv):
     return win_rate_dict
 
 
-def calculate_sharp_ratio(df, col, risk_free_rate):
+def calculate_sharpe_ratio(df, col, risk_free_rate):
     holding_period_day = (df.loc[df.index[-1], 'date'] - df.loc[df.index[0], 'date']).days
     net_profit = df.at[df.index[-1], col] - df.at[df.index[0], col]
 
@@ -531,7 +531,8 @@ def cal_performance(para_combination):
         result_dict['win_rate'] = 0
         result_dict['loss_rate'] = 0
         result_dict['net_profit_to_mdd'] = np.inf
-        result_dict['cov'] = 0
+        result_dict['cov_count'] = 0
+        result_dict['cov_return'] = 0
 
         # Win rate by year
         for year in year_list:
@@ -544,7 +545,7 @@ def cal_performance(para_combination):
         df['year'] = pd.DatetimeIndex(df['date']).year
 
         # Strategy Performance
-        net_profit, holding_period_day, return_on_capital, annualized_return, annualized_std, annualized_sr = calculate_sharp_ratio(
+        net_profit, holding_period_day, return_on_capital, annualized_return, annualized_std, annualized_sr = calculate_sharpe_ratio(
             df, 'equity_value', risk_free_rate)
         mdd_pct, mdd_dollar = calculate_mdd(df, 'equity_value')
         mdd_pct = mdd_pct * -100
@@ -583,19 +584,9 @@ def cal_performance(para_combination):
         else:
             result_dict['net_profit_to_mdd'] = net_profit / mdd_dollar
 
-        # Cov
-        # df3 = df[df['action'] == 'open']
-        df3 = df[df['action'].notnull()]
-        df3 = df3.set_index('date')
-        signal_year_count = df3.groupby(lambda x: x.year).size()
 
-        signal_year_std = np.std(signal_year_count)
-        signal_year_mean = np.mean(signal_year_count)
-        cov = round(signal_year_std / signal_year_mean, 3)
-
-        result_dict['cov_count'] = cov
-
-        # Win rate by year
+        # Count and Win rate by year
+        year_count = []
         for year in year_list:
             try:
                 result_dict[str(year)] = win_rate_dict[year][0]
@@ -606,6 +597,12 @@ def cal_performance(para_combination):
                 result_dict[str(year)] = 0
                 result_dict[f'{year}_win_rate'] = '--'
 
+            year_count.append(result_dict[str(year)])
+
+
+        result_dict['cov_count'] = round(np.std(year_count) / np.mean(year_count), 3)
+
+
         # Performance by year
         first_equity_value = 0
         last_equity_value = 0
@@ -642,7 +639,7 @@ def cal_performance(para_combination):
 
     # BaH Performance
     bah_net_return, holding_period_day, bah_return, \
-    bah_annualized_return, bah_annualized_std, bah_annualized_sr = calculate_sharp_ratio(df, 'close',
+    bah_annualized_return, bah_annualized_std, bah_annualized_sr = calculate_sharpe_ratio(df, 'close',
                                                                                          risk_free_rate)
     initial_capital = df.loc[df.index[0], 'equity_value']
     df['bah_equity_curve'] = df['close'] * initial_capital // df.loc[df.index[0], 'close']
