@@ -26,7 +26,7 @@ class Plot:
     initial_capital = 0
     return_in_capital = 0
     mdd = 0
-    sharp = 0
+    sharpe = 0
 
     start_date_datetime = 0
     end_date_datetime = 0
@@ -40,7 +40,7 @@ class Plot:
     num_of_trade = 0
     num_of_win = 0
     return_on_capital = 0
-    sharp = 0
+    sharpe = 0
     total_commission = 0
     year_list = []
     year_count = []
@@ -609,7 +609,7 @@ class Plot:
                     except:
                         self.num_of_win = '--'
                     self.return_on_capital = df['return_on_capital']
-                    self.sharp = df['annualized_sr']
+                    self.sharpe = df['annualized_sr']
                     self.total_commission = df['total_commission']
                     self.total_commission = df['total_commission']
                     year_count = []
@@ -638,7 +638,7 @@ class Plot:
             if not os.path.isfile('saved_strategies.csv'):
                 columns = ['path','initial','net_profit_to_mdd','net_profit',
                                       'mdd_dollar','mdd_pct','num_of_trade','num_of_win',
-                                      'return_on_capital','total_commission','sharp'
+                                      'return_on_capital','total_commission','sharpe'
                                       ]
                 for year in self.year_list:
                     columns.append(year)
@@ -702,7 +702,7 @@ class Plot:
                                            'num_of_trade':self.num_of_trade,
                                            'num_of_win': self.num_of_win,
                                            'return_on_capital': self.return_on_capital,
-                                           'sharp': self.sharp,
+                                           'sharpe': self.sharpe,
                                            'total_commission': self.total_commission,
                                            }
                                 for i, year in enumerate(self.year_list):
